from flask import Flask, redirect, url_for, request, render_template
import json
app = Flask(__name__)


def add_item(todo, task):
    """Adds a task dictionary."""
    todo.append(task)
    with open("db/list.json", "w") as f:
        f.write(json.dumps(todo))
    return redirect(url_for("retrieve_schedule"))


def del_item(todo, task_id):
    """Deletes a task by index."""
    del todo[int(task_id)]
    with open("db/list.json", "w") as f:
        f.write(json.dumps(todo))
    return redirect(url_for("retrieve_schedule"))


def mark_item(todo, task_id):
    """Marks or unmarks the task as important."""
    todo[int(task_id)]["marked"] = not todo[int(task_id)]["marked"]
    with open("db/list.json", "w") as f:
        f.write(json.dumps(todo))
    return redirect(url_for("retrieve_schedule"))


@app.route("/", methods = ["POST", "GET"])
def retrieve_schedule():
    """Main function.
    Loads in the list.json file as a list of tasks to do,
    and allows the user to add and delete tasks.
    """
    with open("db/list.json", "r") as f:
        todo_list = json.loads(f.read())
    if request.method == "POST":
        type = request.form.get("type")
        if type == "delete":
            del_item(todo_list, request.form.get("id"))
        elif type == "mark":
            mark_item(todo_list, request.form.get("id"))
        elif type == "add":
            task_add = {"header": request.form.get("header"),
                        "text": request.form.get("text"),
                        "deadline": request.form.get("deadline"),
                        "marked": False}
            add_item(todo_list, task_add)
    return render_template("interface.html", result = todo_list)


if __name__ == "__main__":
   app.run()